Python library for Wargaming.net API
====================================

Pure pythonic library for accessing Wargaming.net API (https://wargaming.net/developers/).

Compatible with a Python>=2.7 and Python >=3.4 versions. PyPy also!

.. image:: https://travis-ci.org/svartalf/python-wargaming.svg?branch=master
.. image:: https://readthedocs.org/projects/python-wargaming/badge/?version=latest
.. image:: https://badge.fury.io/py/wargaming.svg

Installation
------------

As simple as usual:

    $ pip install wargaming

Documentation
-------------

Wargaming.NET API documentation: https://na.wargaming.net/developers/api_reference/

Library documentation: http://python-wargaming.rtfd.org

Supported WGAPI
---------------

 * World of Tanks
 * World of Warplanes
 * World of Warships
 * World of Tanks Blitz
 * Wargaming.NET common API

Contribution
------------

Just fork, update and send pull request. Do not forget to run tests:

    $ tox

Also check for a PEP-0008 compliance:

    $ pep8 --max-line-length=120 wargaming
